@@ -118,8 +118,8 @@ class HelpAction(argparse.Action):
 
 class QuantumShell(App):
 
-    CONSOLE_MESSAGE_FORMAT = '%(levelname)s: %(name)s %(message)s'
-
+    CONSOLE_MESSAGE_FORMAT = '%(message)s'
+    DEBUG_MESSAGE_FORMAT = '%(levelname)s: %(name)s %(message)s'
     log = logging.getLogger(__name__)
 
     def __init__(self, apiversion):
@@ -342,6 +342,29 @@ class QuantumShell(App):
         if err:
             self.log.debug('got an error: %s', err)
 
+    def configure_logging(self):
+        """Create logging handlers for any log output.
+        """
+        root_logger = logging.getLogger('')
+
+        # Set up logging to a file
+        root_logger.setLevel(logging.DEBUG)
+
+        # Send higher-level messages to the console via stderr
+        console = logging.StreamHandler(self.stderr)
+        console_level = {0: logging.WARNING,
+                         1: logging.INFO,
+                         2: logging.DEBUG,
+                         }.get(self.options.verbose_level, logging.DEBUG)
+        console.setLevel(console_level)
+        if logging.DEBUG == console_level:
+            formatter = logging.Formatter(self.DEBUG_MESSAGE_FORMAT)
+        else:
+            formatter = logging.Formatter(self.CONSOLE_MESSAGE_FORMAT)
+        console.setFormatter(formatter)
+        root_logger.addHandler(console)
+        return
+
 
 def itertools_compressdef(data, selectors):
     # patch 2.6 compress('ABCDEF', [1,0,1,0,1,1]) --> A C E F
